@@ -27,6 +27,4 @@ def test_message_thread_to_profile():
 
 @util.use_cassette('user_count')
 def test_user_search_count():
-    search = User().search(count=1)
-    import ipdb; ipdb.set_trace()
-    assert len(User().search(count=1))
+    assert len(User().search(count=1)) == 1
